//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include <SI_EFM8UB1_Register_Enums.h>                  // SFR declarations
#include "InitDevice.h"
#include "VCPXpress.h"
#include "descriptor.h"
#include "ThermocoupleSystem_Defs.h"

//-----------------------------------------------------------------------------
// main() Routine
// ----------------------------------------------------------------------------
int main (void)
{
	//call hardware initialization routine
	enter_DefaultMode_from_RESET();

	SFRPAGE = SPI0_PAGE;
	//disable the normal (end-of-byte) SPI interrupt
	SPI0FCN1 &= ~SPI0FCN1_SPIFEN__BMASK;
	//enable the receive FIFO interrupt
	SPI0FCN0 |= SPI0FCN0_RFRQE__BMASK;
	//set FIFO interrupt to fire when we have more than one byte
	SPI0FCN0 |= SPI0FCN0_RXTH__ONE;
	//set slave select logic high (it is an active-low signal)
	SPI0CN0 |= NSS_BIT;

	//VCPXpress initialization
	USB_Init(&InitStruct);

	//enable VCPXpress API interrupts
	API_Callback_Enable(myAPICallback);

	//enable global interrupts
	IE_EA = 1;

	while(1)
	{
		if(TEMP_DATA_REQUESTED == TRUE)
		{
			TEMP_DATA_REQUESTED = FALSE;

			SFRPAGE = SPI0_PAGE;
			//flush the transmit and receive FIFOs
			SPI0FCN0 |= SPI0FCN0_TFLSH__FLUSH;
			SPI0FCN0 |= SPI0FCN0_RFLSH__FLUSH;
			//set slave select logic low
			SPI0CN0 &= ~NSS_BIT;
			/*send two dummy bytes so that we can read
			 16 bits of data from the MAX31855*/
			SPI0DAT = 0x00; SPI0DAT = 0x00;
		}

		if(TEMP_DATA_READY == TRUE)
		{
			TEMP_DATA_READY = FALSE;
			Transmit_USB_Packet();
		}
	}
}
